Module quantamm_math

Module quantamm_math 

Constants

ONE
ONE_SIGNED

Functions

calculate_block_normalised_weight
Calculate the current block weight based on time interpolation
get_first_four_weights_and_multipliers
Extract weights and multipliers from the first four tokens
get_second_four_weights_and_multipliers
Extract weights and multipliers from the remaining tokens