Struct StablePool
Source pub struct StablePool {
pub amp: U256,
}
Stable pool implementation
Get maximum invariant ratio
Get minimum invariant ratio
Perform swap operation
Compute invariant
Compute balance
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.